(* l'interface *)
module type Complexe =
  sig
    type t
	 (* ce serait plus joli d'avoir des "real" a la place des float *)
    val make_complex : float -> float -> t
    val get_re : t -> float
    val get_im : t -> float
    val mult : t -> t -> t
  end

(* et deux implementations *)
module CartesianCompl : Complexe =
  struct
    type t = float*float
    let make_complex x y = x,y
    let get_re = fst
    let get_im = snd
    let mult (x1,y1) (x2,y2) = (x1*.x2-.y1*.y2, x1*.y2+.y1*.x2)
  end

module PolarCompl : Complexe =
  struct
    type t = float*float
    let make_complex x y = sqrt(x*.x+.y*.y),(atan2 y x)
    let get_re (r,th) = r*.cos(th)
    let get_im (r,th) = r*.sin(th)
    let mult (r1,th1) (r2,th2) = (r1*.r2,th1+.th2)
  end
